.. _reference:

*************
API Reference
*************

.. toctree::
   :maxdepth: 2

   coordinates/index
   data
   database
   image
   io
   map
   net
   physics
   sun
   sunpy
   time
   timeseries
   util
   visualization
